# Integration tests specific to Salesforce adapter
#

import os, sys

if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from zope.interface import providedBy
from Products.CMFCore.utils import getToolByName

from Products.Archetypes.public import DisplayList

from Products.PloneFormGen.interfaces import IPloneFormGenField

from Products.salesforcebaseconnector.tests import sfconfig   # get login/pw

from getpaid.SalesforcePloneFormGenAdapter.tests import base
from getpaid.SalesforcePloneFormGenAdapter.config import REQUIRED_MARKER
from getpaid.SalesforcePloneFormGenAdapter.config import SF_ADAPTER_TYPES

class TestProductInstallation(base.GetPaidPFGSalesforceAdapterTestCase):
    """ ensure that our product installs correctly """

    def afterSetUp(self):
        self.types      = self.portal.portal_types
        self.properties = self.portal.portal_properties
        self.factory    = self.portal.portal_factory
        self.skins      = self.portal.portal_skins
        self.workflow   = self.portal.portal_workflow
        self.metaTypes = SF_ADAPTER_TYPES
    
    def testDependenciesInstalled(self):
        DEPENDENCIES = ['PloneFormGen',
                        'DataGridField',
                        'PloneGetPaid',
                        'salesforcepfgadapter']
        
        for depend in DEPENDENCIES:
            self.failUnless(self.portal.portal_quickinstaller.isProductInstalled(depend),
                "Dependency product %s is not already installed" % depend)
        
    def testAdapterTypeRegistered(self):
        for t in self.metaTypes:
            self.failUnless(t in self.types.objectIds())
    
    def testPortalFactorySetup(self):
        for t in self.metaTypes:
            self.failUnless(t in self.factory.getFactoryTypes(),
                "Type %s is not a factory types" % t)

    def testTypesNotSearched(self):
        types_not_searched = self.properties.site_properties.getProperty('types_not_searched')
        for t in self.metaTypes:
            self.failUnless(t in types_not_searched,
                "Type %s is searchable and shouldn't be" % t)

    def testTypesNotListed(self):
        metaTypesNotToList  = self.properties.navtree_properties.getProperty('metaTypesNotToList')
        for t in self.metaTypes:
            self.failUnless(t in metaTypesNotToList,
                "Type %s is will show up in the nav and shouldn't" % t)
    
    def testMetaTypesAllowedInFormFolder(self):
        allowedTypes = self.types.FormFolder.allowed_content_types
        for t in self.metaTypes:
            self.failUnless(t in allowedTypes,
                "Type %s is not addable to the Form Folder" % t)

        # make sure we haven't inadvertently removed other core field and adapter types
        
        # a random sampling of core fields
        coreFields = [
            'FormSelectionField',
            'FormMultiSelectionField',
            'FormLinesField',
            'FormIntegerField',
            'FormBooleanField',
            'FormStringField',
            'FormTextField',
        ]
        
        for t in coreFields:
            self.failUnless(t in allowedTypes,
                "Type %s was accidentally whacked from the Form Fields allowed_content_types" % t)
    
    def testNeededSkinsRegistered(self):
        """Our all important skin layer(s) should be registered with the site."""
        prodSkins = ('salesforce-getpaid-adapter_images',)
        
        for prodSkin in prodSkins:
            self.failUnless(prodSkin in self.skins.objectIds(),
                "The skin %s was not registered with the skins tool" % prodSkin)
    
    def testSkinShowsUpInToolsLayers(self):
        """We need our product's skin directories to show up below custom as one of the called
           upon layers of our skin's properties
        """
        product_layers = ('salesforce-getpaid-adapter_images',)

        for selection, layers in self.skins.getSkinPaths():
            for specific_layer in product_layers:
                self.failUnless(specific_layer in layers, "The %s layer \
                    does not appear in the layers of Plone's %s skin" % (specific_layer,selection))
        
    def testCorePloneLayersStillPresent(self):
        """As was known to happen with legacy versions of GS working with the skins tool,
           it was easy to inadvertently remove need layers for the selected skin.  Here 
           we make sure this hasn't happened.
        """
        core_layers = ('PloneFormGen','plone_templates',)
        
        for selection, layers in self.skins.getSkinPaths():
            for specific_layer in core_layers:
                self.failUnless(specific_layer in layers, "The %s layer \
                    does not appear in the layers of Plone's available skins" % specific_layer)
        
    


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestProductInstallation))
    return suite



""" 
    A plugin for GetPaid that saves orders
    to Salesforce.com after it is charged
"""

__author__  = ''
__docformat__ = 'plaintext'

# Python imorts
import logging

from Products.CMFCore.utils import getToolByName

from getpaid.SalesforceOrderRecorder import SalesforceOrderRecorderMessageFactory as _

# Get Paid events
from getpaid.core.interfaces import workflow_states, IShoppingCartUtility, IShippableOrder, IShippingRateService, IShippableLineItem
from zope.app.component.hooks import getSite

from ZODB.POSException import ConflictError

logger = logging.getLogger("SalesforceOrderRecorder")

def handleOrderWorkflowTransition( order, event ):

    logger.info("handleOrderWorkflowTransition: %s, %s" % (order.finance_state, event.destination));

    # Only save the order if it has moved into the charged state
    # and the order was placed through PloneFormGen and the adapter is enabled
    if order.finance_state == event.destination and event.destination == workflow_states.order.finance.CHARGED:

        try:
            executeAdapter(order)
        except ConflictError:
            raise
        except Exception, e:
            # I catch everything since any uncaught exception here
            # will prevent the order from moving to charged
            logger.error("Exception saving order %s to salesforce: %s" % (order.order_id, e))
        except:
            logger.error("Unknown Exception saving order %s to salesforce" % (order.order_id))


def executeAdapter(order):
    portal_properties = getToolByName(getSite(), 'portal_properties')
    props = getattr(portal_properties, 'getpaidsalesforceorderrecorder')
    refCat = getToolByName( getSite(), 'reference_catalog')
    salesforce = getToolByName(getSite(), 'portal_salesforcebaseconnector')

    # Get the content types that I will map
    itemTypes = props.gpsor_aware_types

    # Loop over the items and see if any are mappable
    itemList = []
    for item in order.shopping_cart.items():
        payable = refCat.lookupObject( item[0] )
        itemType = payable.portal_type

        if itemType in itemTypes:
            itemList.append(item)

    # If there is something in my list then there is at least
    # one item to record
    if len(itemList):
        customerSObject = props.gpsor_salesforce_customer_object
        itemSObject = props.gpsor_salesforce_item_object

        if itemSObject is None or itemSObject == "" or itemSObject == customerSObject:
            # Loop over the items mapping customer and item to same 
            # SFObject I will have multiple SF Objects
            sObject = []
                
            # Loop over cart items creating an sObject for each
            for item in order.shopping_cart.items():
                obj = dict(type=customerSObject)
                sObject.append(obj)

                _mapOrderFields(order, obj, props)
                _mapItemFields(item[1], obj, props)

            results = salesforce.create(sObject)
            for result in results:
                if result['success']:
                    logger.info("Successfully created new %s %s for order %s in Salesforce" % \
                                    (sObject[0]['type'], result['id'], order.order_id))
                else:
                    for error in result['errors']:
                        logger.error('Failed to create new %s for order %s in Salesforce: %s' % \
                                         (sObject[0]['type'], order.order_id, error['message']))
                
        else:
            # Loop over the items mapping customer and item to same SFObject
            # I will have multiple SF Objects

            # first create the customer obejct in SF
            obj = dict(type=customerSObject)

            # I kind of think it's a hack to pass None for the item
            # the method expects it, but in this case will not use
            # it since I'm passing the customer field map.
            _mapOrderFields(order, obj, props)

            results = salesforce.create(obj)
            if results[0]['success']:
                logger.info("Successfully created new %s %s for order %s in Salesforce" % \
                                (obj['type'], results[0]['id'], order.order_id))

                obj['id'] = results[0]['id']

                # Loop over cart items creating an sObject for each
                sObjects = []
                for item in order.shopping_cart.items():
                    itemObj = dict(type=itemSObject)
                    sObjects.append(itemObj)

                    _mapItemFields(item[1], itemObj, props, obj['id'])

                results = salesforce.create(sObjects)
                for result in results:
                    if result['success']:
                        logger.info("Successfully created new %s %s in Salesforce" % \
                                        (sObjects[0]['type'], result['id']))
                    else:
                        for error in result['errors']:
                            logger.error('Failed to create new %s for order %s in Salesforce: %s' % \
                                             (sObjects[0]['type'], order.order_id, error['message']))

            else:
                for error in results['errors']:
                    logger.error('Failed to create new %s for order %s in Salesforce: %s' % \
                                     (obj['type'], order.order_id, error['message']))


def _mapOrderFields(order, sfObject, props):
    if props.gpsor_first_name:
        fullName = order.contact_information.name
        firstName = fullName.split(' ', 1)[0]

        if firstName is not None:
            sfObject[props.gpsor_first_name] = firstName
    
    if props.gpsor_last_name:
        fullName = order.contact_information.name
        lastName = fullName.split(' ', 1)[1]

        if lastName is not None:
            sfObject[props.gpsor_last_name] = lastName

    if props.gpsor_phone:
        if order.contact_information.phone_number is not None:
            sfObject[props.gpsor_phone] = order.contact_information.phone_number
            
    if props.gpsor_email:
        if order.contact_information.email is not None:
            sfObject[props.gpsor_email] = order.contact_information.email

    if props.gpsor_contact_allowed:
        if order.contact_information.marketing_preference is not None:
            sfObject[props.gpsor_contact_allowed] = order.contact_information.marketing_preference

    if props.gpsor_email_format_pref:
        if order.contact_information.email_html_format is not None:
            sfObject[props.gpsor_email_format_pref] = order.contact_information.email_html_format

    if props.gpsor_billing_address_name:
        if order.billing_address.bill_name is not None:
            sfObject[props.gpsor_billing_address_name] = order.billing_address.bill_name

    if props.gpsor_billing_address_org:
        if order.billing_address.bill_organization is not None:
            sfObject[props.gpsor_billing_address_org] = order.billing_address.bill_organization

    if props.gpsor_billing_address_street:
        line_1 = order.billing_address.bill_first_line
        line_2 = order.billing_address.bill_second_line

        if line_2 is None:
            value = line_1
        else:
            value = "\n".join((line_1, line_2))

        if value is not None:
            sfObject[props.gpsor_billing_address_street] = value

    if props.gpsor_billing_address_city:
        if order.billing_address.bill_city is not None:
            sfObject[props.gpsor_billing_address_city] = order.billing_address.bill_city

    if props.gpsor_billing_address_country:
        if order.billing_address.bill_country is not None:
            sfObject[props.gpsor_billing_address_country] = order.billing_address.bill_country

    if props.gpsor_billing_address_state:
        if order.billing_address.bill_state is not None:
            sfObject[props.gpsor_billing_address_state] = order.billing_address.bill_state

    if props.gpsor_billing_address_zip:
        if order.billing_address.bill_postal_code is not None:
            sfObject[props.gpsor_billing_address_zip] = order.billing_address.bill_postal_code

    if props.gpsor_shipping_address_name:
        if order.shipping_address.ship_same_billing:
            value = order.billing_address.bill_name
        else:
            value = order.shipping_address.ship_name

        if value is not None:
            sfObject[props.gpsor_shipping_address_name] = value

    if props.gpsor_shipping_address_org:
        if order.shipping_address.ship_same_billing:
            value = order.billing_address.bill_organization
        else:
            value = order.shipping_address.ship_organization

        if value is not None:
            sfObject[props.gpsor_shipping_address_org] = value

    if props.gpsor_shipping_address_street:
        if order.shipping_address.ship_same_billing:
            line_1 = order.billing_address.bill_first_line
            line_2 = order.billing_address.bill_second_line
        else:
            line_1 = order.shipping_address.ship_first_line
            line_2 = order.shipping_address.ship_second_line

        if line_2 is None:
            value = line_1
        else:
            value = "\n".join((line_1, line_2))

        if value is not None:
            sfObject[props.gpsor_shipping_address_street] = value

    if props.gpsor_shipping_address_city:
        if order.shipping_address.ship_same_billing:
            value = order.billing_address.bill_city
        else:
            value = order.shipping_address.ship_city

        if value is not None:
            sfObject[props.gpsor_shipping_address_city] = value

    if props.gpsor_shipping_address_country:
        if order.shipping_address.ship_same_billing:
            value = order.billing_address.bill_country
        else:
            value = order.shipping_address.ship_country

        if value is not None:
            sfObject[props.gpsor_shipping_address_country] = value

    if props.gpsor_shipping_address_state:
        if order.shipping_address.ship_same_billing:
            value = order.billing_address.bill_state
        else:
            value = order.shipping_address.ship_state

        if value is not None:
            sfObject[props.gpsor_shipping_address_state] = value

    if props.gpsor_shipping_address_zip:
        if order.shipping_address.ship_same_billing:
            value = order.billing_address.bill_postal_code
        else:
            value = order.shipping_address.ship_postal_code

        if value is not None:
            sfObject[props.gpsor_shipping_address_zip] = value

    if props.gpsor_order_id:
        if order.order_id is not None:
                    sfObject[props.gpsor_order_id] = order.order_id

#    if props.gpsor_creation_date:
#        sfObject[props.gpsor_creation_date] = 

    if props.gpsor_order_total:
        if order.getTotalPrice() is not None:
            sfObject[props.gpsor_order_total] = order.getTotalPrice()

    if props.gpsor_transaction_id:
        if order.processor_order_id is not None:
            sfObject[props.gpsor_transaction_id] = order.user_payment_info_trans_id

    if props.gpsor_cc_last_4:
        if order.user_payment_info_last4 is not None:
            sfObject[props.gpsor_cc_last_4] = order.user_payment_info_last4

    if props.gpsor_shipping_service:
        if getShippingService(order) is not None:
            sfObject[props.gpsor_shipping_service] = getShippingService(order)

    if props.gpsor_shipping_method:
        if getShippingMethod(order) is not None:
            sfObject[props.gpsor_shipping_method] = getShippingMethod(order)

    if props.gpsor_shipping_weight:
        if getShipmentWeight(order) is not None:
            sfObject[props.gpsor_shipping_weight] = getShipmentWeight(order)

    if props.gpsor_shipping_cost:
        if order.shipping_cost is not None:
            sfObject[props.gpsor_shipping_cost] = order.shipping_cost

def _mapItemFields(item, sfObject, props, parentSFObjectId=None):

    if parentSFObjectId and props.gpsor_parent_sf_object_id:
        sfObject[props.gpsor_parent_sf_object_id] = parentSFObjectId

    if props.gpsor_item_quantity:
        if item.quantity is not None:
            sfObject[props.gpsor_item_quantity] = item.quantity

    if props.gpsor_item_id:
        if order.shopping_cart.items.item_id is not None:
            sfObject[props.gpsor_item_id] = order.shopping_cart.items.item_id

    if props.gpsor_item_name:
        if item.name is not None:
            sfObject[props.gpsor_item_name] = item.name

    if props.gpsor_product_code:
        if item.product_code is not None:
            sfObject[props.gpsor_product_code] = item.product_code

    if props.gpsor_product_sku:
        if item.sku is not None:
            sfObject[props.gpsor_product_sku] = item.sku

    if props.gpsor_item_cost:
        if item.cost is not None:
            sfObject[props.gpsor_item_cost] = item.cost

    if props.gpsor_total_item_cost:
        totalCost = item.cost * item.quantity
        if totalCost is not None:
            sfObject[props.gpsor_total_item_cost] = totalCost

    if props.gpsor_item_desc:
        if item.description is not None:
            sfObject[props.gpsor_item_desc] = item.description

    if props.gpsor_discount_code:
        value = ""
        annotation = IAnnotations(item[1])
        if "getpaid.discount.code" in annotation:
            value = annotation["getpaid.discount.code"]

            if value is not None:
                sfObject[props.gpsor_discount_code] = value

    if props.gpsor_discount_title:
        value = ""
        annotation = IAnnotations(item[1])
        if "getpaid.discount.code.title" in annotation:
            value = annotation["getpaid.discount.code.title"]

            if value is not None:
                sfObject[props.gpsor_discount_title] = value

    if props.gpsor_discount_total:
        value = ""
        annotation = IAnnotations(item[1])
        if "getpaid.discount.code.discount" in annotation:
            value = annotation["getpaid.discount.code.discount"]

            if value is not None:
                sfObject[props.gpsor_discount_total] = value


def getShippingService(order):
    if not hasattr(order,"shipping_service"):
        return None
    infos = order.shipping_service
    if infos:
        return infos

def getShippingMethod(order):
    # check the traversable wrrapper
    if not IShippableOrder.providedBy( order ):
        return None
    
    service = zope.component.queryUtility( IShippingRateService,
                                           order.shipping_service )
    
    # play nice if the a shipping method is removed from the store
    if not service: 
        return None
        
    return service.getMethodName( order.shipping_method )
    
def getShipmentWeight(order):
    """
    Lets return the weight in lbs for the moment
    """
    # check the traversable wrrapper
    if not IShippableOrder.providedBy( order ):
        return None

    totalShipmentWeight = 0
    for eachProduct in order.shopping_cart.values():
        if IShippableLineItem.providedBy( eachProduct ):
            weightValue = eachProduct.weight * eachProduct.quantity
            totalShipmentWeight += weightValue
    return totalShipmentWeight



from AccessControl import ModuleSecurityInfo
from Products.Archetypes.public import process_types, listTypes
from Products.CMFCore import utils
from Products.CMFCore.DirectoryView import registerDirectory

from getpaid.SalesforceOrderRecorder.config import PROJECTNAME, GLOBALS


# Import "PloneFormGenMessageFactory as _" to create message ids
# in the ploneformgen domain
# Zope 3.1-style messagefactory module
# BBB: Zope 2.8 / Zope X3.0
try:
    from zope.i18nmessageid import MessageFactory
except ImportError:
    from messagefactory_ import SalesforceOrderRecorderMessageFactory
else:
    SalesforceOrderRecorderMessageFactory = MessageFactory('getpaidsalesforceorderrecorder')

# Check for Plone versions
try:
    from Products.CMFPlone.migrations import v2_5
except ImportError:
    HAS_PLONE25 = False
else:
    HAS_PLONE25 = True
try:
    from Products.CMFPlone.migrations import v3_0
except ImportError:
    HAS_PLONE30 = False
else:
    HAS_PLONE30 = True



from getpaid.SalesforceOrderRecorder import preferences
from getpaid.SalesforceOrderRecorder.config import PROJECTNAME
from getpaid.SalesforceOrderRecorder import HAS_PLONE25, HAS_PLONE30
from getpaid.SalesforceOrderRecorder.interfaces import IGetPaidSalesforceOrderRecorderManagementOptions

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.permissions import ManagePortal
from Products.CMFPlone.utils import versionTupleFromString

from StringIO import StringIO

DEPENDENCIES = ('Products.salesforcebaseconnector',)

def install(self):
    out = StringIO()
    
    print >> out, "Installing dependency products"
    portal_qi = getToolByName(self, 'portal_quickinstaller')
    for depend in DEPENDENCIES:
        if portal_qi.isProductInstallable(depend) and not portal_qi.isProductInstalled(depend):
            portal_qi.installProduct(depend)
    
    # run our profile first.  among other things, it sets up our local utility:
    # the Pigeonholizer!!!
    portal_setup.runAllImportStepsFromProfile('profile-getpaid.SalesforceOrderRecorder:default', purge_old=False)
    portal_quickinstaller.notifyInstalled("GetpaidSalesforceOrderRecorder")

    # Set up the settings configlet
    portal = getToolByName( self, 'portal_url').getPortalObject()
    sm = portal.getSiteManager()

    return out.getvalue()


def uninstall(self):
    out = StringIO()
    
    if not reinstall:
        # remove icon from portal_actionicons
        icons = getToolByName(self, 'portal_actionicons')
        if 'getpaidsalesforceorderrecorder' in [a.getActionId().lower() for a in icons.listActionIcons()]:
            icons.removeActionIcon(category='controlpanel', action_id='getpaidsalesforceorderrecorder')

        # remove control panel registration
        ctl = getToolByName(self, 'portal_controlpanel')
        if 'getpaidsalesforceorderrecorder' in [a.getId() for a in ctl.listActions()]:
            ctl.unregisterConfiglet('getpaidsalesforceorderrecorder')

        # remove property sheet
        props = getToolByName(self, 'portal_properties')
        if 'getpaidsalesforceorderrecorder' in props:
            props._delObject('getpaidsalesforceorderrecorder')
        
    print >> out, "\nSuccessfully uninstalled %s." % PROJECTNAME

    return out.getvalue()



# Integration tests specific to Salesforce adapter
#

if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from getpaid.SalesforcePloneFormGenAdapter.tests import base
from getpaid.SalesforcePloneFormGenAdapter.config import SF_ADAPTER_TYPES

from Products.CMFCore.utils import getToolByName

class TestProductUninstallation(base.GetPaidPFGSalesforceAdapterTestCase):
    """ ensure that our product installs correctly """

    def afterSetUp(self):
        self.types      = self.portal.portal_types
        self.properties = self.portal.portal_properties
        self.factory    = self.portal.portal_factory
        self.skins      = self.portal.portal_skins
        self.qi         = self.portal.portal_quickinstaller
        self.workflow   = self.portal.portal_workflow
        self.adapterTypes = SF_ADAPTER_TYPES
        self.metaTypes = self.adapterTypes
        
        # uninstall our product
        if self.qi.isProductInstalled('getpaid.SalesforcePloneFormGenAdapter'):
            self.qi.uninstallProducts(products=['getpaid.SalesforcePloneFormGenAdapter',])
    
    def testDependenciesStillInstalled(self):
        """Just because someone chooses to uninstall the salesforcepfgadapter
           product doesn't mean they want to remove it's dependencies.  This
           should be done manually in addition to uninstalling salesforcepfgadapter.
        """
        DEPENDENCIES = ['PloneFormGen',
                        'DataGridField',
                        'PloneGetPaid',
                        'salesforcepfgadapter']
        
        for depend in DEPENDENCIES:
            self.failUnless(self.qi.isProductInstalled(depend),
                "Dependency product %s is not already installed" % depend)    
    
    def testQIDeemsProductUninstalled(self):
        """Make sure the product is uninstalled in the eyes of the portal_quickinstaller"""
        self.failIf(self.qi.isProductInstalled('GetPaidPFGSalesforceAdapter'))
    
    def testAdapterTypeNotRegisteredOnUninstall(self):
        for t in self.metaTypes:
            self.failIf(t in self.types.objectIds(),
                "Type %s is still registered with the types tool after uninstallation." % t)

    def testFactoryTypesRemovedOnUninstall(self):
        for t in self.metaTypes:
            self.failIf(t in self.factory.getFactoryTypes(),
                "Type %s is still a factory type after uninstallation." % t)

    def testTypesNotSearchedRemovedOnUninstall(self):
        types_not_searched = self.properties.site_properties.getProperty('types_not_searched')
        for t in self.metaTypes:
            self.failIf(t in types_not_searched,
                "Type %s is still in the types_not_searched list after uninstallation" % t)

    def testTypesNotListedRemovedOnUninstall(self):
        metaTypesNotToList  = self.properties.navtree_properties.getProperty('metaTypesNotToList')
        for t in self.metaTypes:
            self.failIf(t in metaTypesNotToList,
                "Type %s is still in the list of metaTypesNotToList after uninstallation" % t)

    def testMetaTypesAllowedInFormFolderRemovedOnUninstall(self):
        allowedTypes = self.types.FormFolder.allowed_content_types
        for t in self.metaTypes:
            self.failIf(t in allowedTypes,
                "Type %s is still listed as addable to the Form Folder after uninstallation" % t)
    
    def testSkinsRemovedOnUninstall(self):
        """Our all important skin layer(s) should be registered with the site."""
        prodSkins = ('salesforce-getpaid-adapter_images',)

        for prodSkin in prodSkins:
            self.failIf(prodSkin in self.skins.objectIds(),
                "The skin %s is still registered with the skins tool after uninstallation" % prodSkin)

    def testSkinLayersRemovedOnUninstall(self):
        """We need our product's skin directories to show up below custom as one of the called
           upon layers of our skin's properties
        """
        product_layers = ('salesforce-getpaid-adapter_images',)
        
        for selection, layers in self.skins.getSkinPaths():
            for specific_layer in product_layers:
                self.failIf(specific_layer in layers, "The %s layer \
                    still appears in the layers of Plone's %s skin after uninstall" % (specific_layer,selection))
    
    def testWorkflowToolNoLongerMaintainsWorkflowChainForRemovedType(self):
        for t in self.metaTypes:
            self.failIf(self.workflow.getChainForPortalType(t))
    
    def testProductInstallsUninstallsCorrectly(self):
        # ensure that we can install/uninstall code correctly
        # this helps ensure that we aren't doing things like
        # deleting/adding property sheet items out of order and
        # with proper fallback -- plus, it helps us get better 
        # output in our --coverage results :)
        
        # ensure installable after uninstall
        self.failUnless(self.qi.isProductInstallable('getpaid.SalesforcePloneFormGenAdapter'))
        self.qi.installProducts(products=['getpaid.SalesforcePloneFormGenAdapter',])
        
        # uninstall product
        self.qi.uninstallProducts(products=['getpaid.SalesforcePloneFormGenAdapter',])
        self.failUnless(self.qi.isProductInstallable('getpaid.SalesforcePloneFormGenAdapter'))
        
    
if  __name__ == '__main__':
    framework()

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestProductUninstallation))
    return suite



## The Project Name
PROJECTNAME = "GetPaidSalesforceOrderRecorder"

## The skins dir
SKINS_DIR = 'skins'

## Globals variable
GLOBALS = globals()

## Required field marker
REQUIRED_MARKER = "(required)"




from zope.app.form.browser import MultiCheckBoxWidget
from zope.app.form.browser import TextAreaWidget
from zope import schema
from zope.formlib.form import FormFields

from zope.interface import Interface
from zope.interface import implements
from zope.component import adapts
from zope.component import getUtility
from plone.app.controlpanel.form import ControlPanelForm
from plone.app.controlpanel.widgets import MultiCheckBoxThreeColumnWidget
from plone.fieldsets.fieldsets import FormFieldsets

from Products.CMFDefault.formlib.schema import SchemaAdapterBase
from Products.CMFPlone.interfaces import IPloneSiteRoot
from Products.CMFCore.utils import getToolByName

class IGetPaidSalesforceOrderRecorderTypes(Interface):

    gpsor_aware_types = schema.Tuple(title=u"Recordable Content Types",
                                     description=u"Which content types should be recorded to Salesforce if they are purchased?",
                                     missing_value=tuple(),
                                     value_type=schema.Choice(vocabulary="plone.app.vocabularies.ReallyUserFriendlyTypes"),
                                     )

    gpsor_salesforce_customer_object = schema.TextLine(title=u"Salesforce Customer Object", 
                                                       description=u"This object will hold the customer, address and potentially order items if no item object is provided", 
                                                       default=None, 
                                                       required=True)

    gpsor_salesforce_item_object = schema.TextLine(title=u"Salesforce Item Object", 
                                                       description=u"This object will hold the order items. It is optional. If blank, the above object will be used, with a new SF record created for each item", 
                                                       default=None, 
                                                       required=False)

    gpsor_parent_sf_object_id = schema.TextLine(title=u"Parent Object Id", 
                                                       description=u"This will hold the id for the related parent salesforce object. This field mapping will be ignored if no object is provided for the items. (see Salesforce Item Object above)", 
                                                       default=None, 
                                                       required=False)


    gpsor_first_name = schema.TextLine(title=u"First Name", 
                                      description=u"", 
                                      default=None, 
                                      required=False)
    
    gpsor_last_name = schema.TextLine(title=u"Last Name", 
                                      description=u"", 
                                      default=None, 
                                      required=False)
    
    gpsor_phone = schema.TextLine(title=u"Phone Number", 
                                  description=u"", 
                                  default=None, 
                                  required=False)
    
    gpsor_email = schema.TextLine(title=u"Email", 
                                  description=u"", 
                                  default=None, 
                                  required=False)
    
    gpsor_contact_allowed = schema.Bool(title=u"Contact Allowed", 
                                        description=u"", 
                                        default=None, 
                                        required=False)
    
    gpsor_email_format_pref = schema.TextLine(title=u"Email Format Preference", 
                                              description=u"", 
                                              default=None, 
                                              required=False)
    
    gpsor_billing_address_name = schema.TextLine(title=u"Billing Address Name", 
                                                 description=u"", 
                                                 default=None, 
                                                 required=False)
    
    gpsor_billing_address_org = schema.TextLine(title=u"Billing Address Organization", 
                                                description=u"", 
                                                default=None, 
                                                required=False)
	
    gpsor_billing_address_street = schema.TextLine(title=u"Billing Address Street", 
                                                   description=u"", 
                                                   default=None, 
                                                   required=False)
    
    gpsor_billing_address_city = schema.TextLine(title=u"Billing Address City", 
                                                 description=u"", 
                                                 default=None, 
                                                 required=False)
    
    gpsor_billing_address_country = schema.TextLine(title=u"Billing Address Country", 
                                                    description=u"", 
                                                    default=None, 
                                                    required=False)
    
    gpsor_billing_address_state = schema.TextLine(title=u"Billing Address State", 
                                                  description=u"", 
                                                  default=None, 
                                                  required=False)
    
    gpsor_billing_address_zip = schema.TextLine(title=u"Billing Address Zip", 
                                                description=u"", 
                                                default=None, 
                                                required=False)
    
    gpsor_shipping_address_name = schema.TextLine(title=u"Shipping Address Name", 
                                                  description=u"", 
                                                  default=None, 
                                                  required=False)
    
    gpsor_shipping_address_org = schema.TextLine(title=u"Shipping Address Organization", 
                                                 description=u"", 
                                                 default=None, 
                                                 required=False)
    
    gpsor_shipping_address_street = schema.TextLine(title=u"Shipping Address Street", 
                                                    description=u"", 
                                                    default=None, 
                                                    required=False)
    
    gpsor_shipping_address_city = schema.TextLine(title=u"Shipping Address City", 
                                                  description=u"", 
                                                  default=None, 
                                                  required=False)
    
    gpsor_shipping_address_country = schema.TextLine(title=u"Shipping Address Country", 
                                                     description=u"", 
                                                     default=None, 
                                                     required=False)
    
    gpsor_shipping_address_state = schema.TextLine(title=u"Shipping Address State", 
                                                   description=u"", 
                                                   default=None, 
                                                   required=False)
    
    gpsor_shipping_address_zip = schema.TextLine(title=u"Shipping Address Zip", 
                                                 description=u"", 
                                                 default=None, 
                                                 required=False)
    
    gpsor_order_id = schema.TextLine(title=u"Order Id", 
                                     description=u"", 
                                     default=None, 
                                     required=False)
    
#Creation Date
#    gpsor_creation_date = schema.TextLine(title=u"", 
#                                              description=u"", 
#                                              default=None, 
#                                              required=False)
    
    gpsor_order_total = schema.TextLine(title=u"Order Total", 
                                        description=u"", 
                                        default=None, 
                                        required=False)
    
    gpsor_transaction_id = schema.TextLine(title=u"Transaction Id", 
                                           description=u"", 
                                           default=None, 
                                           required=False)
    
    gpsor_cc_last_4 = schema.TextLine(title=u"Cc Last 4", 
                                      description=u"", 
                                      default=None, 
                                      required=False)
    
    gpsor_shipping_service = schema.TextLine(title=u"Shipping Service", 
                                             description=u"", 
                                             default=None, 
                                             required=False)
    
    gpsor_shipping_method = schema.TextLine(title=u"Shipping Method", 
                                            description=u"", 
                                            default=None, 
                                            required=False)
    
    gpsor_shipping_weight = schema.TextLine(title=u"Shipping Weight", 
                                            description=u"", 
                                            default=None, 
                                            required=False)
    
    gpsor_shipping_cost = schema.TextLine(title=u"Shipping Cost", 
                                          description=u"", 
                                          default=None, 
                                          required=False)
    
    gpsor_item_quantity = schema.TextLine(title=u"Order Item Quantity", 
                                          description=u"", 
                                          default=None, 
                                          required=False)
    
    gpsor_item_id = schema.TextLine(title=u"Order Item Id", 
                                    description=u"", 
                                    default=None, 
                                    required=False)
    
    gpsor_item_name = schema.TextLine(title=u"Order Item Name", 
                                      description=u"", 
                                      default=None, 
                                      required=False)
    
    gpsor_product_code = schema.TextLine(title=u"Order Item Product Code", 
                                         description=u"", 
                                         default=None, 
                                         required=False)
    
    gpsor_product_sku = schema.TextLine(title=u"Order Item SKU", 
                                        description=u"", 
                                        default=None, 
                                        required=False)
    
    gpsor_item_cost = schema.TextLine(title=u"Order Item Cost", 
                                      description=u"", 
                                      default=None, 
                                      required=False)
    
    gpsor_total_item_cost = schema.TextLine(title=u"Total Order Item Cost", 
                                            description=u"", 
                                            default=None, 
                                            required=False)
    
    gpsor_item_desc = schema.TextLine(title=u"Order Item Description", 
                                      description=u"", 
                                      default=None, 
                                      required=False)
    
    gpsor_discount_code = schema.TextLine(title=u"Order Item Discount Code", 
                                          description=u"", 
                                          default=None, 
                                          required=False)
    
    gpsor_discount_title = schema.TextLine(title=u"Order Item Discount Title", 
                                           description=u"", 
                                           default=None, 
                                           required=False)
    
    gpsor_discount_total = schema.TextLine(title=u"Order Item Discount Total", 
                                           description=u"", 
                                           default=None, 
                                           required=False)
    

class GetPaidSalesforceOrderRecorderCPAdapter(SchemaAdapterBase):
    adapts(IPloneSiteRoot)
    implements(IGetPaidSalesforceOrderRecorderTypes)

    def __init__(self, context):
        super(GetPaidSalesforceOrderRecorderCPAdapter, self).__init__(context)
        portal_properties = getToolByName(context, 'portal_properties')
        self.gpsor_props = getattr(portal_properties, 'getpaidsalesforceorderrecorder')


    def set_gpsor_aware_types(self, value):
        self.gpsor_props.gpsor_aware_types = value

    def get_gpsor_aware_types(self):
        return self.gpsor_props.gpsor_aware_types
    gpsor_aware_types = property(get_gpsor_aware_types, set_gpsor_aware_types)

    def set_gpsor_salesforce_customer_object(self, value):
        self.gpsor_props.gpsor_salesforce_customer_object = value

    def get_gpsor_salesforce_customer_object(self):
        return self.gpsor_props.gpsor_salesforce_customer_object
    gpsor_salesforce_customer_object = property(get_gpsor_salesforce_customer_object, set_gpsor_salesforce_customer_object)

    def set_gpsor_salesforce_item_object(self, value):
        self.gpsor_props.gpsor_salesforce_item_object = value

    def get_gpsor_salesforce_item_object(self):
        return self.gpsor_props.gpsor_salesforce_item_object
    gpsor_salesforce_item_object = property(get_gpsor_salesforce_item_object, set_gpsor_salesforce_item_object)

    def set_gpsor_parent_sf_object_id(self, value):
        self.gpsor_props.gpsor_parent_sf_object_id = value

    def get_gpsor_parent_sf_object_id(self):
        return self.gpsor_props.gpsor_parent_sf_object_id
    gpsor_parent_sf_object_id = property(get_gpsor_parent_sf_object_id, set_gpsor_parent_sf_object_id)

    def set_gpsor_first_name(self, value):
        self.gpsor_props.gpsor_first_name = value

    def get_gpsor_first_name(self):
        return self.gpsor_props.gpsor_first_name
    gpsor_first_name = property(get_gpsor_first_name, set_gpsor_first_name)

    def set_gpsor_last_name(self, value):
        self.gpsor_props.gpsor_last_name = value

    def get_gpsor_last_name(self):
        return self.gpsor_props.gpsor_last_name
    gpsor_last_name = property(get_gpsor_last_name, set_gpsor_last_name)

    def set_gpsor_phone(self, value):
        self.gpsor_props.gpsor_phone = value

    def get_gpsor_phone(self):
        return self.gpsor_props.gpsor_phone
    gpsor_phone = property(get_gpsor_phone, set_gpsor_phone)

    def set_gpsor_email(self, value):
        self.gpsor_props.gpsor_email = value

    def get_gpsor_email(self):
        return self.gpsor_props.gpsor_email
    gpsor_email = property(get_gpsor_email, set_gpsor_email)

    def set_gpsor_contact_allowed(self, value):
        self.gpsor_props.gpsor_contact_allowed = value

    def get_gpsor_contact_allowed(self):
        return self.gpsor_props.gpsor_contact_allowed
    gpsor_contact_allowed = property(get_gpsor_contact_allowed, set_gpsor_contact_allowed)

    def set_gpsor_email_format_pref(self, value):
        self.gpsor_props.gpsor_email_format_pref = value

    def get_gpsor_email_format_pref(self):
        return self.gpsor_props.gpsor_email_format_pref
    gpsor_email_format_pref = property(get_gpsor_email_format_pref, set_gpsor_email_format_pref)

    def set_gpsor_billing_address_name(self, value):
        self.gpsor_props.gpsor_billing_address_name = value

    def get_gpsor_billing_address_name(self):
        return self.gpsor_props.gpsor_billing_address_name
    gpsor_billing_address_name = property(get_gpsor_billing_address_name, set_gpsor_billing_address_name)

    def set_gpsor_billing_address_org(self, value):
        self.gpsor_props.gpsor_billing_address_org = value

    def get_gpsor_billing_address_org(self):
        return self.gpsor_props.gpsor_billing_address_org
    gpsor_billing_address_org = property(get_gpsor_billing_address_org, set_gpsor_billing_address_org)

    def set_gpsor_billing_address_street(self, value):
        self.gpsor_props.gpsor_billing_address_street = value

    def get_gpsor_billing_address_street(self):
        return self.gpsor_props.gpsor_billing_address_street
    gpsor_billing_address_street = property(get_gpsor_billing_address_street, set_gpsor_billing_address_street)

    def set_gpsor_billing_address_city(self, value):
        self.gpsor_props.gpsor_billing_address_city = value

    def get_gpsor_billing_address_city(self):
        return self.gpsor_props.gpsor_billing_address_city
    gpsor_billing_address_city = property(get_gpsor_billing_address_city, set_gpsor_billing_address_city)

    def set_gpsor_billing_address_country(self, value):
        self.gpsor_props.gpsor_billing_address_country = value

    def get_gpsor_billing_address_country(self):
        return self.gpsor_props.gpsor_billing_address_country
    gpsor_billing_address_country = property(get_gpsor_billing_address_country, set_gpsor_billing_address_country)

    def set_gpsor_billing_address_state(self, value):
        self.gpsor_props.gpsor_billing_address_state = value

    def get_gpsor_billing_address_state(self):
        return self.gpsor_props.gpsor_billing_address_state
    gpsor_billing_address_state = property(get_gpsor_billing_address_state, set_gpsor_billing_address_state)

    def set_gpsor_billing_address_zip(self, value):
        self.gpsor_props.gpsor_billing_address_zip = value

    def get_gpsor_billing_address_zip(self):
        return self.gpsor_props.gpsor_billing_address_zip
    gpsor_billing_address_zip = property(get_gpsor_billing_address_zip, set_gpsor_billing_address_zip)

    def set_gpsor_shipping_address_name(self, value):
        self.gpsor_props.gpsor_shipping_address_name = value

    def get_gpsor_shipping_address_name(self):
        return self.gpsor_props.gpsor_shipping_address_name
    gpsor_shipping_address_name = property(get_gpsor_shipping_address_name, set_gpsor_shipping_address_name)

    def set_gpsor_shipping_address_org(self, value):
        self.gpsor_props.gpsor_shipping_address_org = value

    def get_gpsor_shipping_address_org(self):
        return self.gpsor_props.gpsor_shipping_address_org
    gpsor_shipping_address_org = property(get_gpsor_shipping_address_org, set_gpsor_shipping_address_org)

    def set_gpsor_shipping_address_street(self, value):
        self.gpsor_props.gpsor_shipping_address_street = value

    def get_gpsor_shipping_address_street(self):
        return self.gpsor_props.gpsor_shipping_address_street
    gpsor_shipping_address_street = property(get_gpsor_shipping_address_street, set_gpsor_shipping_address_street)

    def set_gpsor_shipping_address_city(self, value):
        self.gpsor_props.gpsor_shipping_address_city = value

    def get_gpsor_shipping_address_city(self):
        return self.gpsor_props.gpsor_shipping_address_city
    gpsor_shipping_address_city = property(get_gpsor_shipping_address_city, set_gpsor_shipping_address_city)

    def set_gpsor_shipping_address_country(self, value):
        self.gpsor_props.gpsor_shipping_address_country = value

    def get_gpsor_shipping_address_country(self):
        return self.gpsor_props.gpsor_shipping_address_country
    gpsor_shipping_address_country = property(get_gpsor_shipping_address_country, set_gpsor_shipping_address_country)

    def set_gpsor_shipping_address_state(self, value):
        self.gpsor_props.gpsor_shipping_address_state = value

    def get_gpsor_shipping_address_state(self):
        return self.gpsor_props.gpsor_shipping_address_state
    gpsor_shipping_address_state = property(get_gpsor_shipping_address_state, set_gpsor_shipping_address_state)

    def set_gpsor_shipping_address_zip(self, value):
        self.gpsor_props.gpsor_shipping_address_zip = value

    def get_gpsor_shipping_address_zip(self):
        return self.gpsor_props.gpsor_shipping_address_zip
    gpsor_shipping_address_zip = property(get_gpsor_shipping_address_zip, set_gpsor_shipping_address_zip)

    def set_gpsor_order_id(self, value):
        self.gpsor_props.gpsor_order_id = value

    def get_gpsor_order_id(self):
        return self.gpsor_props.gpsor_order_id
    gpsor_order_id = property(get_gpsor_order_id, set_gpsor_order_id)

    def set_gpsor_creation_date(self, value):
        self.gpsor_props.gpsor_creation_date = value

    def get_gpsor_creation_date(self):
        return self.gpsor_props.gpsor_creation_date
    gpsor_creation_date = property(get_gpsor_creation_date, set_gpsor_creation_date)

    def set_gpsor_order_total(self, value):
        self.gpsor_props.gpsor_order_total = value

    def get_gpsor_order_total(self):
        return self.gpsor_props.gpsor_order_total
    gpsor_order_total = property(get_gpsor_order_total, set_gpsor_order_total)

    def set_gpsor_transaction_id(self, value):
        self.gpsor_props.gpsor_transaction_id = value

    def get_gpsor_transaction_id(self):
        return self.gpsor_props.gpsor_transaction_id
    gpsor_transaction_id = property(get_gpsor_transaction_id, set_gpsor_transaction_id)

    def set_gpsor_cc_last_4(self, value):
        self.gpsor_props.gpsor_cc_last_4 = value

    def get_gpsor_cc_last_4(self):
        return self.gpsor_props.gpsor_cc_last_4
    gpsor_cc_last_4 = property(get_gpsor_cc_last_4, set_gpsor_cc_last_4)

    def set_gpsor_shipping_service(self, value):
        self.gpsor_props.gpsor_shipping_service = value

    def get_gpsor_shipping_service(self):
        return self.gpsor_props.gpsor_shipping_service
    gpsor_shipping_service = property(get_gpsor_shipping_service, set_gpsor_shipping_service)

    def set_gpsor_shipping_method(self, value):
        self.gpsor_props.gpsor_shipping_method = value

    def get_gpsor_shipping_method(self):
        return self.gpsor_props.gpsor_shipping_method
    gpsor_shipping_method = property(get_gpsor_shipping_method, set_gpsor_shipping_method)

    def set_gpsor_shipping_weight(self, value):
        self.gpsor_props.gpsor_shipping_weight = value

    def get_gpsor_shipping_weight(self):
        return self.gpsor_props.gpsor_shipping_weight
    gpsor_shipping_weight = property(get_gpsor_shipping_weight, set_gpsor_shipping_weight)

    def set_gpsor_shipping_cost(self, value):
        self.gpsor_props.gpsor_shipping_cost = value

    def get_gpsor_shipping_cost(self):
        return self.gpsor_props.gpsor_shipping_cost
    gpsor_shipping_cost = property(get_gpsor_shipping_cost, set_gpsor_shipping_cost)

    def set_gpsor_item_quantity(self, value):
        self.gpsor_props.gpsor_item_quantity = value

    def get_gpsor_item_quantity(self):
        return self.gpsor_props.gpsor_item_quantity
    gpsor_item_quantity = property(get_gpsor_item_quantity, set_gpsor_item_quantity)

    def set_gpsor_item_id(self, value):
        self.gpsor_props.gpsor_item_id = value

    def get_gpsor_item_id(self):
        return self.gpsor_props.gpsor_item_id
    gpsor_item_id = property(get_gpsor_item_id, set_gpsor_item_id)

    def set_gpsor_item_name(self, value):
        self.gpsor_props.gpsor_item_name = value

    def get_gpsor_item_name(self):
        return self.gpsor_props.gpsor_item_name
    gpsor_item_name = property(get_gpsor_item_name, set_gpsor_item_name)

    def set_gpsor_product_code(self, value):
        self.gpsor_props.gpsor_product_code = value

    def get_gpsor_product_code(self):
        return self.gpsor_props.gpsor_product_code
    gpsor_product_code = property(get_gpsor_product_code, set_gpsor_product_code)

    def set_gpsor_product_sku(self, value):
        self.gpsor_props.gpsor_product_sku = value

    def get_gpsor_product_sku(self):
        return self.gpsor_props.gpsor_product_sku
    gpsor_product_sku = property(get_gpsor_product_sku, set_gpsor_product_sku)

    def set_gpsor_item_cost(self, value):
        self.gpsor_props.gpsor_item_cost = value

    def get_gpsor_item_cost(self):
        return self.gpsor_props.gpsor_item_cost
    gpsor_item_cost = property(get_gpsor_item_cost, set_gpsor_item_cost)

    def set_gpsor_total_item_cost(self, value):
        self.gpsor_props.gpsor_total_item_cost = value

    def get_gpsor_total_item_cost(self):
        return self.gpsor_props.gpsor_total_item_cost
    gpsor_total_item_cost = property(get_gpsor_total_item_cost, set_gpsor_total_item_cost)

    def set_gpsor_item_desc(self, value):
        self.gpsor_props.gpsor_item_desc = value

    def get_gpsor_item_desc(self):
        return self.gpsor_props.gpsor_item_desc
    gpsor_item_desc = property(get_gpsor_item_desc, set_gpsor_item_desc)

    def set_gpsor_discount_code(self, value):
        self.gpsor_props.gpsor_discount_code = value

    def get_gpsor_discount_code(self):
        return self.gpsor_props.gpsor_discount_code
    gpsor_discount_code = property(get_gpsor_discount_code, set_gpsor_discount_code)

    def set_gpsor_discount_title(self, value):
        self.gpsor_props.gpsor_discount_title = value

    def get_gpsor_discount_title(self):
        return self.gpsor_props.gpsor_discount_title
    gpsor_discount_title = property(get_gpsor_discount_title, set_gpsor_discount_title)

    def set_gpsor_discount_total(self, value):
        self.gpsor_props.gpsor_discount_total = value

    def get_gpsor_discount_total(self):
        return self.gpsor_props.gpsor_discount_total
    gpsor_discount_total = property(get_gpsor_discount_total, set_gpsor_discount_total)


fs_gpsortypes = FormFieldsets(IGetPaidSalesforceOrderRecorderTypes)
fs_gpsortypes.id = 'gpsortypes'
fs_gpsortypes.label = u'Types Settings'

class PHMultiCheckBoxWidget(MultiCheckBoxWidget):

    def __init__(self, field, request):
        """Initialize the widget."""
        super(MultiCheckBoxWidget, self).__init__(field,
            field.value_type.vocabulary, request)

class GetPaidSalesforceOrderRecorderCP(ControlPanelForm):

    form_fields = FormFieldsets(fs_gpsortypes)

    # title of the page
    label = "GetPaid Salesforce Order Recorder Settings"

    # explanatory text
    description = u"""Map a content type to an adapter"""

    # fieldset legend
    form_name = "GetPaid Salesforce Order Recorder Settings"
    form_fields['gpsor_aware_types'].custom_widget = MultiCheckBoxThreeColumnWidget



# Import the base test case classes
from Testing import ZopeTestCase as ztc
from Products.Five import zcml
from Products.CMFPlone.tests import PloneTestCase as ptc
from Products.PloneTestCase.layer import onsetup
from Products.CMFCore.utils import getToolByName
import getpaid.SalesforcePloneFormGenAdapter

from Products.salesforcebaseconnector.tests import sfconfig   # get login/pw

from Products.PloneGetPaid.tests.base import PloneGetPaidFunctionalTestCase

# These must install cleanly, ZopeTestCase will take care of the others
ztc.installProduct('PloneFormGen')
ztc.installProduct('DataGridField')
ztc.installProduct('salesforcebaseconnector')
ztc.installProduct('salesforcepfgadapter')
ztc.installProduct('PloneGetPaid')

#ztc.installProduct('GetPaidPFGSalesforceAdapter')

# Set up the Plone site used for the test fixture. The PRODUCTS are the products
# to install in the Plone site (as opposed to the products defined above, which
# are all products available to Zope in the test fixture)
PRODUCTS = ['salesforcepfgadapter',
            'PloneGetPaid',
            'getpaid.SalesforcePloneFormGenAdapter',
            'getpaid.formgen']

@onsetup
def setupZCML():
    zcml.load_config('configure.zcml', getpaid.SalesforcePloneFormGenAdapter)
    ztc.installPackage('getpaid.SalesforcePloneFormGenAdapter')
    ztc.installPackage('getpaid.formgen')

setupZCML()
ptc.setupPloneSite(products=PRODUCTS)

class GetPaidPFGSalesforceAdapterTestCase(ptc.PloneTestCase):
    """Base class for integration tests for the 'GetPaidPFGSalesforceAdapter' product. This may
    provide specific set-up and tear-down operations, or provide convenience
    methods.
    """

class BaseGetPaidPFGSalesforceAdapterFunctionalTestCase(PloneGetPaidFunctionalTestCase):
    """Base class for functional doctests
    """
    def afterSetUp(self):
        PloneGetPaidFunctionalTestCase.afterSetUp(self)

        self.portal.manage_addProduct['salesforcebaseconnector'].manage_addTool('Salesforce Base Connector', None)
        self.salesforce = getToolByName(self.portal, "portal_salesforcebaseconnector")
        self.salesforce.setCredentials(sfconfig.USERNAME, sfconfig.PASSWORD)
        self._todelete = list() # keep track of ephemeral test data to delete
        self.folder.invokeFactory('FormFolder', 'ff1')
        self.ff1 = getattr(self.folder, 'ff1')
    

# class FakeRequest(dict):

#     def __init__(self, **kwargs):
#         self.form = kwargs



import unittest
import doctest

from Testing import ZopeTestCase as ztc

from getpaid.SalesforcePloneFormGenAdapter.tests import base

testfiles = (
    'pfg_adapter_view.txt',
)

def test_suite():
    return unittest.TestSuite([

        # Test the control panel
        ztc.FunctionalDocFileSuite(
            f, package='getpaid.SalesforcePloneFormGenAdapter.tests',
            test_class=base.BaseGetPaidPFGSalesforceAdapterFunctionalTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS)
        
            for f in testfiles
        ])

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')



from setuptools import setup, find_packages
import os

version = open(os.path.join("getpaid", "SalesforceOrderRecorder", "version.txt")).read().strip()

setup(name='getpaid.SalesforceOrderRecorder',
      version=version,
      description="GetPaid plugin allowing for storage or orders in Salesforce.com",
      long_description=open(os.path.join("getpaid", "SalesforceOrderRecorder", "README.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Zope2",
        "Framework :: Plone",
        ],
      keywords='Zope CMF Plone Salesforce.com CRM integration',
      author='Rob LaRubbio',
      author_email='rob@onenw.org',
      url='http://code.google.com/p/getpaid',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['getpaid'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'beatbox>=0.9,<=1.0dev',
          'Products.salesforcebaseconnector'
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



"""

Annotation Property Storage and Site Configuration Settings

$Id: preferences.py 1720 2008-08-07 02:02:44Z rs_alves@aeiou.pt $
"""

from getpaid.core.options import PersistentBag
from zope import component
import interfaces

def ConfigurationPreferences( site ):

    settings = component.queryUtility(interfaces.IGetPaidSalesforceOrderRecorderManagementOptions)

    # store access to the site, because our vocabularies get the setting as context
    # and want to access portal tools to construct various vocabs
    settings._v_site = site
    return settings

_OrderRecorderSettings = PersistentBag.makeclass( interfaces.IGetPaidSalesforceOrderRecorderManagementOptions )

class OrderRecorderSettings( _OrderRecorderSettings ):

    _v_site = None
    
    @property
    def context( self ):
        return self._v_site

    def manage_fixupOwnershipAfterAdd( self ): pass


